Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: ui/views/widget/widget.cc

Issue 933893003: Use standard icon/title in global error bubble (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/widget/widget.cc
diff --git a/ui/views/widget/widget.cc b/ui/views/widget/widget.cc
index 76dc14a5ae8208608a863b53297f229b85fc7d32..a2700e50607307be3136ce5402dbef71cc0f075f 100644
--- a/ui/views/widget/widget.cc
+++ b/ui/views/widget/widget.cc
@@ -356,8 +356,10 @@ void Widget::Init(const InitParams& in_params) {
non_client_view_->set_client_view(widget_delegate_->CreateClientView(this));
non_client_view_->SetOverlayView(widget_delegate_->CreateOverlayView());
SetContentsView(non_client_view_);
- // Initialize the window's title before setting the window's initial bounds;
- // the frame view's preferred height may depend on the presence of a title.
+ // Initialize the window's icon and title before setting the window's
+ // initial bounds; the frame view's preferred height may depend on the
+ // presence of an icon or a title.
+ UpdateWindowIcon();
UpdateWindowTitle();
non_client_view_->ResetWindowControls();
SetInitialBounds(params.bounds);
« ui/views/bubble/bubble_frame_view.cc ('K') | « ui/views/bubble/bubble_frame_view.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698